@@ -3,7 +3,7 @@
 #' @usage dataset(scientificname = NULL, taxonid = NULL, datasetid = NULL,
 #'   nodeid = NULL, areaid = NULL, startdate = NULL, enddate = NULL,
 #'   startdepth = NULL, enddepth = NULL, geometry = NULL, redlist = NULL,
-#'   exclude = NULL, verbose = FALSE)
+#'   hab = NULL, exclude = NULL, verbose = FALSE)
 #' @param scientificname the scientific name.
 #' @param taxonid the taxon identifier (WoRMS AphiaID).
 #' @param datasetid the dataset identifier.
@@ -15,6 +15,7 @@
 #' @param enddepth the maximum depth below the sea surface.
 #' @param geometry a WKT geometry string.
 #' @param redlist include only IUCN Red List species.
+#' @param hab include only IOC-UNESCO HAB species.
 #' @param exclude quality flags to be excluded from the results.
 #' @param verbose logical. Optional parameter to enable verbose logging (default = \code{FALSE}).
 #' @return The datasets.
@@ -35,6 +36,7 @@ dataset <- function(
   enddepth = NULL,
   geometry = NULL,
   redlist = NULL,
+  hab = NULL,
   exclude = NULL,
   verbose = FALSE
 ) {
@@ -59,6 +61,7 @@ dataset <- function(
       enddepth = enddepth,
       geometry = geometry,
       redlist = handle_logical(redlist),
+      hab = handle_logical(hab),
       exclude = handle_vector(exclude),
       skip = skip,
       size = page_size()
@@ -92,5 +95,5 @@ dataset <- function(
   }
 
   data <- bind_rows(result_list)
-  return(data)
+  return(as_tibble(data))
 }
