@@ -15,5 +15,5 @@ node <- function() {
   data <- res$results
   fetched <- nrow(res$results)
   log_progress(fetched, total)
-  return(data)
+  return(as_tibble(data))
 }
